==> haskell-glib-0.13.6.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: glib
version: 0.13.6.0
id: glib-0.13.6.0-9WyksbQqaBrBk6GEam8kYQ
key: glib-0.13.6.0-9WyksbQqaBrBk6GEam8kYQ
license: LGPL-2.1-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
author: Axel Simon, Duncan Coutts
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.
category: System
abi: 3af83d9103a38ca9fa1cf5ed410436ca
exposed: True
exposed-modules:
    System.Glib System.Glib.Attributes System.Glib.FFI
    System.Glib.Flags System.Glib.GDateTime System.Glib.GError
    System.Glib.GList System.Glib.GObject System.Glib.GParameter
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.MainLoop
    System.Glib.Properties System.Glib.Signals System.Glib.StoreValue
    System.Glib.Types System.Glib.UTFString System.Glib.Utils
import-dirs: /usr/lib/ghc-8.6.3/site-local/glib-0.13.6.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/glib-0.13.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/glib-0.13.6.0
hs-libraries: HSglib-0.13.6.0-9WyksbQqaBrBk6GEam8kYQ
extra-libraries:
    gobject-2.0 glib-2.0
include-dirs: /usr/include/glib-2.0 /usr/lib/glib-2.0/include
              /usr/lib/libffi-3.2.1/include
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html: /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glib-0.13.7.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: glib
version: 0.13.7.0
id: glib-0.13.7.0-CouBN9URvtcKaGTE3xPXLR
key: glib-0.13.7.0-CouBN9URvtcKaGTE3xPXLR
license: LGPL-2.1-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
author: Axel Simon, Duncan Coutts
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.
category: System
abi: 06baffed2a90ae4f807909147ce9d986
exposed: True
exposed-modules:
    System.Glib System.Glib.Attributes System.Glib.FFI
    System.Glib.Flags System.Glib.GDateTime System.Glib.GError
    System.Glib.GList System.Glib.GObject System.Glib.GParameter
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.MainLoop
    System.Glib.Properties System.Glib.Signals System.Glib.StoreValue
    System.Glib.Types System.Glib.UTFString System.Glib.Utils
import-dirs: /usr/lib/ghc-8.6.3/site-local/glib-0.13.7.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/glib-0.13.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/glib-0.13.7.0
hs-libraries: HSglib-0.13.7.0-CouBN9URvtcKaGTE3xPXLR
extra-libraries:
    gobject-2.0 glib-2.0
include-dirs: /usr/include/glib-2.0 /usr/lib/glib-2.0/include
              /usr/lib/libffi-3.2.1/include
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html: /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
